(infrastructure-index)=
# Infrastructure

Learn how to deploy NeMo Gym and plan cluster resources for training.

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`server;1.5em;sd-mr-1` Deployment Topology
:link: deployment-topology
:link-type: doc
Server deployment patterns and training framework integration.
+++
{bdg-secondary}`deployment` {bdg-secondary}`topology` {bdg-secondary}`training-integration`
:::

:::{grid-item-card} {octicon}`note;1.5em;sd-mr-1` Engineering Notes
:link: engineering-notes/index
:link-type: doc
Technical notes on infrastructure decisions and design rationale.
+++
{bdg-secondary}`engineering-notes` {bdg-secondary}`case-studies`
:::

::::
